==> haskell-adjunctions-4.4-28-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.4
id: adjunctions-4.4-7NeQwOGTUZwEtiaUUs15cD
key: adjunctions-4.4-7NeQwOGTUZwEtiaUUs15cD
license: BSD-3-Clause
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors.
category: Data Structures, Adjunctions
abi: 32a7ad92c75731e7752ef8298e96c981
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
import-dirs: /usr/lib/ghc-8.4.3/site-local/adjunctions-4.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/adjunctions-4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/adjunctions-4.4
hs-libraries: HSadjunctions-4.4-7NeQwOGTUZwEtiaUUs15cD
depends:
    array-0.5.2.0 base-4.11.1.0 comonad-5.0.3-4v7nuSEPdIgBetSmkb18fm
    containers-0.5.11.0 contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr
    distributive-0.5.3-965UA3IOt3u9On3XjmkGHE
    free-5.0.2-HgHfyJaNE258DZmQ5rLWWU mtl-2.2.2
    profunctors-5.2.2-KdWNFetrcSrCHbDg3crInJ
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    semigroupoids-5.2.2-JN0Iyx1GXG3I17PeKac8zV transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.3-4v7nuSEPdIgBetSmkb18fm=6275d7cdedf67fa735e89804aadcdd64
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr=c99faff75f3a482d24cfc7bf782693a7
             distributive-0.5.3-965UA3IOt3u9On3XjmkGHE=27afbec73939ed6c0caf9e2b2493bd83
             free-5.0.2-HgHfyJaNE258DZmQ5rLWWU=968fe7aec9567e964e91c4091b77ab30
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             profunctors-5.2.2-KdWNFetrcSrCHbDg3crInJ=aa097a8875a5aeac7cc50b794f28178a
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=a77bb2a04ac30650821b1fe6972fa094
             semigroupoids-5.2.2-JN0Iyx1GXG3I17PeKac8zV=d2ed7244fbf87d5e4b6b0644b4344bf5
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=d1de746fbfbe471314dbcb65b5e13ec4
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.4-36-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.4
id: adjunctions-4.4-HrForpU0rsOIyYVzjAQQ5j
key: adjunctions-4.4-HrForpU0rsOIyYVzjAQQ5j
license: BSD-3-Clause
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors.
category: Data Structures, Adjunctions
abi: 50c2e25b72c839d3e5918f0b7a907063
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
import-dirs: /usr/lib/ghc-8.4.3/site-local/adjunctions-4.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/adjunctions-4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/adjunctions-4.4
hs-libraries: HSadjunctions-4.4-HrForpU0rsOIyYVzjAQQ5j
depends:
    array-0.5.2.0 base-4.11.1.0 comonad-5.0.4-1wEpSKXSOqdDu1P6kQFIcu
    containers-0.5.11.0 contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr
    distributive-0.5.3-GkLJRNLD9XiKYtfBOojYeK
    free-5.1-4OdmiHxhNC4BBxjOvZsZyY mtl-2.2.2
    profunctors-5.3-4mxrwQjuqn81hFPy69nOnA
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    semigroupoids-5.3.1-c86yxBHNerIbUiyudjhsi transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.4-1wEpSKXSOqdDu1P6kQFIcu=de701dde6e417b727d21ef4c1b62174e
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr=c99faff75f3a482d24cfc7bf782693a7
             distributive-0.5.3-GkLJRNLD9XiKYtfBOojYeK=951f97a89da13cd82c5faf083ce86816
             free-5.1-4OdmiHxhNC4BBxjOvZsZyY=0e71701d42031b7b2f6e35d724ca1e62
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             profunctors-5.3-4mxrwQjuqn81hFPy69nOnA=58eb5f2f51b1a3600a850d5373d0b219
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             semigroupoids-5.3.1-c86yxBHNerIbUiyudjhsi=da0cd4cb324a601bf35afe2c3b5af4fd
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=d1de746fbfbe471314dbcb65b5e13ec4
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
